.. currentmodule:: pvlib


Incident angle modifiers
------------------------

.. autosummary::
   :toctree: ../generated/

   iam.physical
   iam.ashrae
   iam.martin_ruiz
   iam.martin_ruiz_diffuse
   iam.sapm
   iam.interp
   iam.marion_diffuse
   iam.marion_integrate
   iam.schlick
   iam.schlick_diffuse
